@@ -96,9 +96,9 @@ class Entry_formular:
         self.header = tk.Label(self.frame, text="AMIVA-F analysis of mutations in variants of human Filamin C", font="Helvetica 16 bold", fg="black")
         self.header.grid(row=0, column=0, sticky="nswe", ipady=5)
         self.label1 = tk.Label(self.frame, text="Please enter your mutation of interest into the entry field below. \n"
-                                                "Accepted format: e.g H1929P \n"
-                                                "for Histidine being substituted by Proline in the mutation at position"
-                                                " 1929 according to UniProt Q14315")
+                                                "Accepted format: e.g M82K \n"
+                                                "for Methionine being substituted by Lysine in the mutation at position"
+                                                " 82 according to UniProt Q14315")
         self.label1.grid(row=1, column=0, ipadx=10, columnspan=2, sticky="news")
 
         # entry + button for amino acid substitution
@@ -128,10 +128,24 @@ class Entry_formular:
                          "C": 7, "Q": 10, "N": 9, "T": 8, "S": 7, "E": 10, "D": 9, "K": 10, "H": 11,
                          "R": 12}
 
-        "unelegant solution to retrieve IDS e.g H1928P, K82R ... from user after preparation because WEKAs outfile " \
+        "unelegant solution to retrieve IDS e.g I1928P, K82R ... from user after preparation because WEKAs outfile " \
         "will not contain information about the mutation names... it will just be ->  1: yes   2:no   3:no " \
         "in order to prevent information loss if one user wants multiple mutations to be classified this info will be " \
         "saved"
+
+        """Clear all entries before run/ so that prior runs don't get overwritten"""
+
+        for entries in entryids:
+            entries.delete(0,"end")
+        entry_form.var.set(1)
+        entry_form.var1.set(1)
+        entry_form.var2.set(1)
+        entry_form.var3.set(1)
+        entry_form.phosphosites_entry.delete(0,"end")
+        del intro_form.phosphohits       #removal of hits and opening of empty list
+        intro_form.phosphohits = []      #new empty list for next round of mutations
+        entry_form.addinfoentry.delete(0,"end")
+
         global mutation_ids
         mutation_ids = []
         #retrieve information from user and calculate SASA, dAtom, dHydrophobicity
@@ -143,6 +157,8 @@ class Entry_formular:
         global pos
         pos = entry_start[1:-1]
 
+
+
         # SASA calculations
         #self.msg1 = tk.messagebox.showinfo("Wildtype.pdb", "In order to generate your parameters"
         #                                                   " you will now need to provide the wildtype .pdb file"
@@ -254,6 +270,7 @@ class Entry_formular:
                     self.entry1.delete(0)
                     self.entry1.insert(0, aa_wt)           #we correct the first position with the correct amino acid in the entry field
                     entry_start = self.entry1.get()        #also grab the correct amino acid for further downstream calculation (not only in the entry formular)
+
                 else:
                     messagebox.showerror("Wrong amino acid!","Cant proceed with wrong amino acid! \nLeaving the application now")
                     root.after(2000, root.destroy())
@@ -336,8 +353,11 @@ class Entry_formular:
             """
 
         #entry_form.r1clash.select()
+        try:
+            index_hit = trgt.index(min(trgt))  # fish out the best hit
+        except:
+            index_hit = 0
 
-        index_hit = trgt.index(min(trgt))  # fish out the best hit
         cmd.frame(index_hit)
         #print(index_hit)
         cmd.get_wizard().apply()
@@ -1089,6 +1109,7 @@ class Entryfield:
     def wekaprediction(self):
         """Here we will do the wekabridging and the prediction for the mutations"""
         jvm.start()
+        self.clearweka()   #remove old stuff before new entries
         data_dir = r"./WEKA_associated_files"
         loader = Loader(classname="weka.core.converters.ArffLoader")
         data = loader.load_file(data_dir + "/AMIVA_trainingset.arff")
@@ -1115,14 +1136,37 @@ class Entryfield:
             resultconf =dist.tolist()
             prediction_disease_dict[inst.class_attribute.value(int(pred))] = resultconf[1]
 
+        #self.clear_btn()     #if something old is still there, remove it now
         #print("The prediction for your submitted mutation and its associated confidence are:")
+
+        # collecting variables for later output file
+        global parameterlist
+        parameterlist = []  # we fill this list with the precalculated parameters
+        parameterlist.append(intro_form.entry1.get())
+        for userinput in entryids[0:-1]:
+            if userinput.get() == "":
+                parameterlist.append("?")
+            else:
+                parameterlist.append(userinput.get())
+
+        parameterlist.append(self.var.get())
+        parameterlist.append(self.var1.get())
+        parameterlist.append(self.var2.get())
+        parameterlist.append(self.var3.get())
+        if self.SAPentry.get() == "":
+            parameterlist.append("?")
+        else:
+            parameterlist.append(self.SAPentry.get())
+        parameterlist.append(self.phosphosites_entry.get())
+        parameterlist.append(self.addinfoentry.get())
+
         for keys, values in prediction_disease_dict.items():
             if keys == "yes":
                 self.wekaentrydis.insert(0, "disease related")
                 #self.wekaentryconf.insert(0, round(values,2))
                 self.wekaentrydis.config(foreground="red", font="Helvetica 18 bold")
                 #self.wekaentryconf.config(font="Helvetica 18")
-                self.wekaentryid.insert(0, intro_form.entry1.get())
+                self.wekaentryid.insert(0, parameterlist[0])
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0, domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
@@ -1131,7 +1175,7 @@ class Entryfield:
                 #self.wekaentryconf.insert(0, round(values,2))
                 #self.wekaentryconf.config(font="Helvetica 18 bold")
                 self.wekaentrydis.config(foreground="green", font="Helvetica 18 bold")
-                self.wekaentryid.insert(0,intro_form.entry1.get())
+                self.wekaentryid.insert(0, parameterlist[0])
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0,domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
@@ -1139,6 +1183,7 @@ class Entryfield:
 
 
 
+
         #self.wekatxt = tk.Label(self.frame6, text=intro_form.entry1.get())
         #self.wekatxt.grid(row=1, column=2, sticky="w")
 
@@ -1147,24 +1192,22 @@ class Entryfield:
     def outputfilemutant(self):
         """Write an outfile that contains the calculated values and their associated predictions together with the
         corresponding labels that identify the calculated values"""
+
+        attributeshown = ["Mutation of interest" ,"Absolute SASA mutant",
+                          "Absolute SASA wildtype",
+                          "Relative SASA wildtype", "Relative SASA mutant", "Δ Number of atoms",
+                          "Δ Hydrophobicity",
+                          "Δ Accessibility (upon mutation)",
+                          "Clashes AND/OR binding partner interference AND/OR phosphosite",
+                          "Sidechain_orientation", "Secondary structure", "SAP score per residue", "posttranslational modifciation sites (8A cutoff)",
+                          "binding partners (8A cutoff)"]
         lstmerge = []
 
         mutfilename = self.wekaentryid.get()
         dirtarget = "./WEKA_associated_files/" + mutfilename + ".txt"
         with open(dirtarget, "w", encoding="utf-8") as mutfh:
-            for userinput in entryids[0:-1]:  #exclude SAP
-                if userinput.get() == "":
-                    lstmerge.append("?")
-                    continue
-                lstmerge.append(str(userinput.get()))
-            lstmerge.append(self.var.get())
-            lstmerge.append(self.var1.get())
-            lstmerge.append(self.var2.get())
-            lstmerge.append(self.var3.get())
-            if self.SAPentry.get() == "":
-                lstmerge.append("?")
-            else:
-                lstmerge.append(self.SAPentry.get())
+            for parameters in parameterlist:          #we will fill the parameters obtained to this new list (redundant work)
+                lstmerge.append(parameters)
             #lstmerge.append(self.phosphosites_entry.get())
 
             mutfh.write("AMIVA-F analysis of mutations in variants of human Filamin C\n\n")
@@ -1176,12 +1219,6 @@ class Entryfield:
                 mutfh.write(str(a))
                 mutfh.write("\n")
 
-            if len(intro_form.phosphohits) == 0:
-                mutfh.write("\nNo posttranslational modifications found within 8Å surrounding\n\n")
-            else:
-                mutfh.write("\nFound the following posttranslational modification positions within 8Å surrounding:\n")
-                for entries in intro_form.phosphohits:
-                    mutfh.write(str(entries) + "\n")
 
 
             mutfh.write("\nThe mutation of interest and its prediction:\n\n")
@@ -1212,7 +1249,7 @@ class Entryfield:
             mutfh.write(str(evl_summary))
             mutfh.write("\n")
             mutfh.write(str(evl_class_details))
-
+            
 
 
 
@@ -1315,6 +1352,8 @@ class Entryfield:
                 outfile1.write(",")
                 outfile1.write("?")
 
+
+
     def add_mutants(self):
         """This function will add additional mutations to the file of to be predicted mutants"""
         with open("./mutation_to_be_predicted.arff", "a") as outfile1:
